@@ -1003,6 +1003,9 @@ int burn_scsi_setup_drive(struct burn_drive *d, int bus_no, int host_no,
 	/* ts A61106 */
 	d->silent_on_scsi_error = 0;
 
+	/* ts B21023 */
+	d->had_particular_error = 0;
+
 
 	d->idata = calloc(1, sizeof(struct burn_scsi_inquiry_data));
 	d->mdata = calloc(1, sizeof(struct scsi_mode_data));
@@ -1459,10 +1462,20 @@ static char *scsi_command_name(unsigned int c, int flag)
 		return "READ DISC STRUCTURE";
         case 0xb6:
 		return "SET STREAMING";
+        case 0xb9:
+		return "READ CD MSF";
         case 0xbb:
 		return "SET CD SPEED";
         case 0xbe:
 		return "READ CD";
+
+#ifdef Libburn_develop_quality_scaN
+
+        case 0xf3:
+		return "NEC/OPTIARC REPORT ERROR RATE";
+
+#endif /* Libburn_develop_quality_scaN */
+
 	}
 	return "(NOT IN LIBBURN COMMAND LIST)";
 }
@@ -1576,7 +1589,7 @@ int scsi_show_command_reply(unsigned char *opcode, int data_dir,
 	if (data_dir != FROM_DRIVE)
 		return 2;
 	if (opcode[0] == 0x28 || opcode[0] == 0x3C ||
-	    opcode[0] == 0xA8 || opcode[0] == 0xBE) {
+	    opcode[0] == 0xA8 || opcode[0] == 0xB9 || opcode[0] == 0xBE) {
 							/* READ commands */
 		/* >>> report amount of data */;
 
