@@ -1,7 +1,7 @@
 /* -*- indent-tabs-mode: t; tab-width: 8; c-basic-offset: 8; -*- */
 
 /* Copyright (c) 2004 - 2006 Derek Foreman, Ben Jansens
-   Copyright (c) 2006 - 2010 Thomas Schmitt <scdbackup@gmx.net>
+   Copyright (c) 2006 - 2012 Thomas Schmitt <scdbackup@gmx.net>
    Provided under GPL version 2 or later.
 */
 
@@ -21,6 +21,7 @@ void spc_select_error_params(struct burn_drive *,
 void spc_getcaps(struct burn_drive *d);
 void spc_sense_write_params(struct burn_drive *);
 void spc_select_write_params(struct burn_drive *,
+			     struct burn_session *, int,
 			     const struct burn_write_opts *);
 void spc_probe_write_modes(struct burn_drive *);
 void spc_request_sense(struct burn_drive *d, struct buffer *buf);
@@ -28,7 +29,8 @@ int spc_block_type(enum burn_block_types b);
 int spc_get_erase_progress(struct burn_drive *d);
 
 /* ts A70315 : test_unit_ready with result parameters */
-int spc_test_unit_ready_r(struct burn_drive *d, int *key, int *asc, int *ascq);
+int spc_test_unit_ready_r(struct burn_drive *d, int *key, int *asc, int *ascq,
+				int *progress);
 
 int spc_test_unit_ready(struct burn_drive *d);
 
@@ -68,15 +70,30 @@ int scsi_init_command(struct command *c, unsigned char *opcode, int oplen);
 /* ts A91106 */
 int scsi_show_cmd_text(struct command *c, void *fp, int flag);
 
-/* ts A91106 */
-int scsi_show_cmd_reply(struct command *c, void *fp, int flag);
+/* ts B11110 */
+/** Logs command (before execution). */
+int scsi_log_command(unsigned char *opcode, int oplen, int data_dir,
+                     unsigned char *data, int bytes,
+                     void *fp_in, int flag);
 
 /* ts A91218 (former sg_log_cmd ts A70518) */
-/** Logs command (before execution) */
+/** Legacy frontend to scsi_log_command() */
 int scsi_log_cmd(struct command *c, void *fp, int flag);
 
+/* ts B11110 */
+/** Logs outcome of a sg command.
+    @param flag  bit0 causes an error message 
+                 bit1 do not print duration
+*/
+int scsi_log_reply(unsigned char *opcode, int data_dir, unsigned char *data,
+                   int dxfer_len, void *fp_in, unsigned char sense[18],
+                   int sense_len, int duration, int flag);
+
 /* ts A91221 (former sg_log_err ts A91108) */
-/** Logs outcome of a sg command. */
+/** Legacy frontend to scsi_log_reply().
+    @param flag  bit0 causes an error message
+                 bit1 do not print duration
+*/
 int scsi_log_err(struct command *c, void *fp, unsigned char sense[18], 
                  int sense_len, int duration, int flag);
 
@@ -95,12 +112,45 @@ int scsi_eval_cmd_outcome(struct burn_drive *d, struct command *c, void *fp_in,
                         int duration, time_t start_time, int timeout_ms,
 			int loop_count, int flag);
 
+
 /* The waiting time before eventually retrying a failed SCSI command.
    Before each retry wait Libburn_scsi_retry_incR longer than with
-   the previous one.
+   the previous one. At most wait for Libburn_scsi_retry_umaX microseconds.
 */
 #define Libburn_scsi_retry_usleeP 100000
 #define Libburn_scsi_retry_incR   100000
+#define Libburn_scsi_retry_umaX   500000
 
+/* The retry waiting time for commands WRITE(10) and WRITE(12).
+*/
+#define Libburn_scsi_write_retry_usleeP     0
+#define Libburn_scsi_write_retry_incR    2000
+#define Libburn_scsi_write_retry_umaX   25000
+
+
+/* ts B11124 */
+/* Millisecond timeout for quickly responding SPC, SBC, and MMC commands */
+#define Libburn_scsi_default_timeouT          30000
+
+/* WRITE(10) and WRITE(12) */
+#define Libburn_scsi_write_timeouT           200000
+
+/* RESERVE TRACK */
+#define Libburn_mmc_reserve_timeouT          200000
+
+/* CLOSE TRACK/SESSION (with Immed bit) */
+#define Libburn_mmc_close_timeouT            200000
+
+/* BLANK , FORMAT UNIT (with Immed bit) */
+#define Libburn_mmc_blank_timeouT            200000
+
+/* SEND OPC INFORMATION */
+#define Libburn_mmc_opc_timeouT              200000
+
+/* MMC_SYNC_CACHE */
+#define Libburn_mmc_sync_timeouT             200000
+
+/* START STOP UNIT with Start bit and Load bit set */
+#define Libburn_mmc_load_timeouT             300000
 
 #endif /*__SPC*/
