@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2007 Vreixo Formoso
  * Copyright (c) 2007 Mario Danic
- * Copyright (c) 2011 Thomas Schmitt
+ * Copyright (c) 2011-2012 Thomas Schmitt
  *
  * This file is part of the libisofs project; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 2 
@@ -21,6 +21,7 @@
 #include "eltorito.h"
 #include "libisofs.h"
 #include "util.h"
+#include "ecma119.h"
 
 
 #include <stdlib.h>
@@ -332,11 +333,12 @@ int joliet_create_mangled_name(uint16_t *dest, uint16_t *src, int digits,
 
     if (ext[0] != (uint16_t)0) {
         size_t extlen = ucslen(ext);
-        dest[pos++] = (uint16_t)0x2E00; /* '.' in big endian UCS */
+        iso_msb((uint8_t *) (dest + pos), 0x002E, 2); /* '.' in UCS */ 
+        pos++;
         ucsncpy(dest + pos, ext, extlen);
         pos += extlen;
     }
-    dest[pos] = (uint16_t)0;
+    iso_msb((uint8_t *) (dest + pos), 0, 2);
     free(ucsnumber);
     return ISO_SUCCESS;
 }
@@ -758,6 +760,7 @@ void write_one_dir_record(Ecma119Image *t, JolietNode *node, int file_id,
             : (uint8_t*)node->name;
 
     struct ecma119_dir_record *rec = (struct ecma119_dir_record*)buf;
+    IsoNode *iso;
 
     len_dr = 33 + len_fi + ((len_fi % 2) ? 0 : 1);
 
@@ -797,7 +800,15 @@ void write_one_dir_record(Ecma119Image *t, JolietNode *node, int file_id,
     rec->len_dr[0] = len_dr;
     iso_bb(rec->block, block - t->eff_partition_offset, 4);
     iso_bb(rec->length, len, 4);
-    iso_datetime_7(rec->recording_time, t->now, t->always_gmt);
+
+    /* was: iso_datetime_7(rec->recording_time, t->now, t->always_gmt);
+    */
+    iso= node->node;
+    iso_datetime_7(rec->recording_time, 
+                   (t->dir_rec_mtime & 2) ? ( t->replace_timestamps ?
+                                              t->timestamp : iso->mtime )
+                                          : t->now, t->always_gmt);
+
     rec->flags[0] = ((node->type == JOLIET_DIR) ? 2 : 0) | (multi_extend ? 0x80 : 0);
     iso_bb(rec->vol_seq_number, (uint32_t) 1, 2);
     rec->len_fi[0] = len_fi;
@@ -902,9 +913,7 @@ int joliet_writer_write_vol_desc(IsoImageWriter *writer)
     ucsncpy_pad((uint16_t*)vol.abstract_file_id, abstract_file_id, 37);
     ucsncpy_pad((uint16_t*)vol.bibliographic_file_id, biblio_file_id, 37);
 
-    iso_datetime_17(vol.vol_creation_time, t->now, t->always_gmt);
-    iso_datetime_17(vol.vol_modification_time, t->now, t->always_gmt);
-    iso_datetime_17(vol.vol_effective_time, t->now, t->always_gmt);
+    ecma119_set_voldescr_times(writer, (struct ecma119_pri_vol_desc *) &vol);
     vol.file_structure_version[0] = 1;
 
     free(vol_id);
