@@ -132,7 +132,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->add_plainly= 0;
  m->split_size= 0;
  strcpy(m->list_delimiter, "--");
- m->ino_behavior= 7;
+ m->ino_behavior= 1 | 2 | 4 | 32;      /* off:no_lsl_count */
  m->iso_level= 3;
  m->iso_level_is_default= 1;
  m->do_joliet= 0;
@@ -268,6 +268,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
    m->appended_part_types[i]= 0;
  }
  m->ascii_disc_label[0]= 0;
+ m->grub2_sparc_core[0]= 0;
  memset(m->hfsp_serial_number, 0, 8);
  m->hfsp_block_size= 0;
  m->apm_block_size= 0;
