@@ -99,15 +99,18 @@ struct CheckmediajoB {
  int max_lba;        /* if >=0 : read up to this address, else use mode */
  
  int min_block_size; /* granularity desired by user
-                     */ 
+                     */
+ int async_chunks;   /* >= 2 : run MD5 thread, use given number of chunks
+                        else : synchronous
+                     */
  int mode;           /* 0= track by track
-                        1= single sweep over libisoburn media capacity
-                        2= single sweep over libburn media capacity
+                        1= single sweep over libisoburn medium capacity
+                        2= single sweep over libburn medium capacity
                      */
  time_t start_time;  
  int time_limit;     /* Number of seconds after which to abort */
  
- int item_limit;     /* Maximum number of media check list items as result */
+ int item_limit;     /* Maximum number of medium check list items as result */
  
  char abort_file_path[SfileadrL];
 
