@@ -49,7 +49,7 @@ int Xorriso_cdrskin_help(struct XorrisO *xorriso, int flag)
 {
  static char helptext[][80]= {
 "Usage: xorriso -as cdrecord [options|source_addresses]",
-"Note: This is not cdrecord. See xorriso -help, xorriso -version, man xorriso",
+"Note: This is not cdrecord. See xorriso -help, xorriso -version, man xorrecord",
 "Options:",
 "\t-version\tprint version information and exit emulation",
 "\t--devices\tprint list of available MMC drives and exit emulation",
@@ -583,7 +583,7 @@ int Xorriso_genisofs_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "--old-root-no-md5", "--old-root-devno", "--old-root-no-ino",
     "--no_rc", "--norock", "-hfsplus", "-fat", "-chrp-boot-part",
     "-isohybrid-gpt-basdat", "-isohybrid-gpt-hfsplus",
-    "-isohybrid-apm-hfsplus",
+    "-isohybrid-apm-hfsplus", "--grub2-boot-info",
     ""
  };
  static char arg1_options[][41]= {
@@ -618,7 +618,8 @@ int Xorriso_genisofs_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "-isohybrid-mbr", "-e", "-partition_offset", "-partition_hd_cyl",
     "-partition_sec_hd", "-partition_cyl_align", "-untranslated_name_len",
     "-rr_reloc_dir", "-hfsplus-serial-no", "-prep-boot-part", "-efi-boot-part",
-    "-hfsplus-block-size", "-apm-block-size",
+    "-hfsplus-block-size", "-apm-block-size", "--grub2-mbr",
+    "--grub2-sparc-core",
     ""
  };
  static char arg2_options[][41]= {
@@ -675,12 +676,12 @@ int Xorriso_genisofs_ignore(struct XorrisO *xorriso, char *whom,
    "-L", "-no-bak", "-no-cache-inodes",
    "-no-split-symlink-components", "-no-split-symlink-fields", "-nobak",
    "-force-rr", "-T",
-   "-no-iso-translate",
+   "-no-iso-translate", "-gui",
    ""
  };
  static char ignored_arg1_options[][41]= {
    "-check-session", "-hide-hfs", "-hide-hfs-list",
-   "-table-name", "-volset-seqno", "-volset-size",
+   "-table-name", "-volset-seqno", "-volset-size", "-sort",
    ""
  };
  int k;
@@ -817,6 +818,7 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -hard-disk-boot             Boot image is a hard disk image",
 "  -no-emul-boot               Boot image is 'no emulation' image",
 "  -boot-info-table            Patch boot image with info table",
+"  --grub2-boot-info           Patch boot image at byte 2548",
 "  -eltorito-id ID             Set El Torito Id String",
 "  -eltorito-selcrit HEXBYTES  Set El Torito Selection Criteria",
 "  -isohybrid-gpt-basdat       Mark El Torito boot image as Basic Data in GPT",
@@ -833,6 +835,7 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -mipsel-boot FILE           Set mipsel boot image name (relative to image root)",
 "  -B FILES, -sparc-boot FILES Set sparc boot image names",
 "  -sparc-label label text     Set sparc boot disk label",
+"  --grub2-sparc-core FILE     Set path of core file for disk label patching",
 "  -efi-boot-part DISKFILE|--efi-boot-image",
 "                              Set data source for EFI System Partition",
 "  -chrp-boot-part             Mark ISO image size by MBR partition type 0x41",
@@ -842,6 +845,7 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  --modification-date=YYYYMMDDhhmmsscc",
 "                              Override date of creation and modification",
 "  -isohybrid-mbr FILE         Set SYSLINUX mbr/isohdp[fp]x*.bin for isohybrid",
+"  --grub2-mbr FILE            Set GRUB2 MBR for boot image address patching",
 #ifdef Xorriso_with_isohybriD
 "  isolinux_mbr=on|auto|off    Control eventual isohybrid MBR generation",
 #endif
@@ -1083,6 +1087,50 @@ ex:;
 }
 
 
+int Xorriso_genisofs_path_pecul(struct XorrisO *xorriso, int *was_path,
+                                int with_emul_toc, int *allow_dir_id_ext,
+                                int *iso_level, int flag)
+{
+ char *sfe= NULL;
+ int ret;
+
+ if(*was_path) {
+   ret= 1; goto ex;
+ }
+ *was_path= 1;
+
+ Xorriso_alloc_meM(sfe, char, 5*SfileadrL);
+
+ /* Enforce odd mkisofs defaults on first pathspec */
+ xorriso->pacifier_style= 1;
+ if(xorriso->allow_dir_id_ext_dflt && *allow_dir_id_ext < 0)
+   *allow_dir_id_ext= 1;
+ if(*allow_dir_id_ext == 1) {
+   Xorriso_relax_compliance(xorriso, "allow_dir_id_ext", 0);
+   *allow_dir_id_ext= 2;
+ }
+ if(xorriso->iso_level_is_default && *iso_level < 0)
+   *iso_level= 1;
+ if(*iso_level >= 1 && *iso_level <= 3) {
+   sprintf(sfe, "iso_9660_level=%d", *iso_level);
+   Xorriso_relax_compliance(xorriso, sfe, 0);
+   iso_level= 0;
+ }
+ /* For the sake of compatibility give up emulated multi-session by default
+ */
+ if(with_emul_toc == 0)
+   xorriso->no_emul_toc|= 1;
+ /* mkisofs records mtime in ECMA-119 and Joliet
+ */
+ Xorriso_relax_compliance(xorriso, "rec_mtime", 0);
+
+ Xorriso_free_meM(sfe);
+ ret= 1;
+ex:;
+ return(ret);
+}
+
+
 /* micro emulation of mkisofs */
 int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
                      int argc, char **argv, int flag)
@@ -1576,12 +1624,15 @@ not_enough_args:;
        ret= 0; goto ex;
      }
      i++;
-     was_path= 1;
      xorriso->pacifier_style= 1;
      ret= Xorriso_option_path_list(xorriso, argv[i],
                                    (strcmp(argpt, "--quoted_path_list")==0));
      if(ret<=0)
        goto problem_handler_2;
+     ret = Xorriso_genisofs_path_pecul(xorriso, &was_path, with_emul_toc,
+                                       &allow_dir_id_ext, &iso_level, 0);
+     if(ret <= 0)
+       goto ex;
    } else if(strcmp(argpt, "-f")==0 || strcmp(argpt, "-follow-links")==0) {
      /* was already handled in first argument scan */;
    } else if(strcmp(argpt, "-pad")==0) {
@@ -1673,6 +1724,7 @@ not_enough_args:;
    } else if(strcmp(argpt, "-no-emul-boot")==0 ||
              strcmp(argpt, "-hard-disk-boot")==0 ||
              strcmp(argpt, "-boot-info-table")==0 ||
+             strcmp(argpt, "--grub2-boot-info") == 0 ||
              strncmp(argpt, "isolinux_mbr=", 13)==0 ||
              strcmp(argpt, "-eltorito-alt-boot")==0 ||
              strcmp(argpt, "--protective-msdos-label")==0 ||
@@ -1701,7 +1753,8 @@ not_enough_args:;
              strcmp(argpt, "-partition_hd_cyl") == 0 ||
              strcmp(argpt, "-partition_sec_hd") == 0 ||
              strcmp(argpt, "-partition_cyl_align") == 0 ||
-             strcmp(argpt, "-isohybrid-mbr")==0) {
+             strcmp(argpt, "-isohybrid-mbr") == 0 ||
+             strcmp(argpt, "--grub2-mbr") == 0) {
      if(i+1>=argc)
        goto not_enough_args;
      delay_opt_list[delay_opt_count++]= i;
@@ -1907,10 +1960,21 @@ not_enough_args:;
      }
 
    } else if(strcmp(argpt, "-sparc-label") == 0) {
+     if(i+1>=argc)
+       goto not_enough_args;
      i++;
      strncpy(xorriso->ascii_disc_label, argv[i], Xorriso_disc_label_sizE - 1);
      xorriso->ascii_disc_label[Xorriso_disc_label_sizE - 1] = 0;
 
+   } else if(strcmp(argpt, "--grub2-sparc-core") == 0) {
+     if(i+1>=argc)
+       goto not_enough_args;
+     i++;
+     sprintf(sfe, "grub2_sparc_core=%s", argv[i]);
+     ret= Xorriso_option_boot_image(xorriso, "any", sfe, 0);
+     if(ret <= 0)
+       goto problem_handler_2;
+
    } else if(strcmp(argpt, "--stdio_sync")==0) {
      if(i+1>=argc)
        goto not_enough_args;
@@ -2065,30 +2129,11 @@ rr_reloc_dir:;
      if(ret<=0)
        goto problem_handler_2;
 
-     was_path= 1;
-
      /* Enforce odd mkisofs defaults on first pathspec */
-     xorriso->pacifier_style= 1;
-     if(xorriso->allow_dir_id_ext_dflt && allow_dir_id_ext < 0)
-       allow_dir_id_ext= 1;
-     if(allow_dir_id_ext == 1) {
-       Xorriso_relax_compliance(xorriso, "allow_dir_id_ext", 0);
-       allow_dir_id_ext= 2;
-     }
-     if(xorriso->iso_level_is_default && iso_level < 0)
-       iso_level= 1;
-     if(iso_level >= 1 && iso_level <= 3) {
-       sprintf(sfe, "iso_9660_level=%d", iso_level);
-       Xorriso_relax_compliance(xorriso, sfe, 0);
-       iso_level= 0;
-     }
-     /* For the sake of compatibility give up emulated multi-session by default
-     */
-     if(with_emul_toc == 0)
-       xorriso->no_emul_toc|= 1;
-     /* mkisofs records mtime in ECMA-119 and Joliet
-     */
-     Xorriso_relax_compliance(xorriso, "rec_mtime", 0);
+     ret = Xorriso_genisofs_path_pecul(xorriso, &was_path, with_emul_toc,
+                                       &allow_dir_id_ext, &iso_level, 0);
+     if(ret <= 0)
+       goto ex;
    }
  continue; /* regular bottom of loop */
 problem_handler_2:;
@@ -2177,6 +2222,9 @@ problem_handler_2:;
      xorriso->boot_emul_default= 0;
    } else if(strcmp(argpt, "-boot-info-table")==0) {
      xorriso->patch_isolinux_image= (xorriso->patch_isolinux_image & ~2) | 1;
+   } else if(strcmp(argpt, "--grub2-boot-info") == 0) {
+     xorriso->patch_isolinux_image=
+                                  (xorriso->patch_isolinux_image & ~2) | 512;
    } else if(strcmp(argpt, "-b") == 0 ||
              strcmp(argpt, "-eltorito-boot") == 0 ||
              strcmp(argpt, "--efi-boot") == 0 ||
@@ -2268,7 +2316,8 @@ problem_handler_2:;
    } else if(strcmp(argpt, "--embedded-boot")==0 ||
              strcmp(argpt, "-generic-boot")==0 ||
              strcmp(argpt, "-G") == 0 ||
-             strcmp(argpt, "-isohybrid-mbr")==0) {
+             strcmp(argpt, "-isohybrid-mbr") == 0 ||
+             strcmp(argpt, "--grub2-mbr") == 0) {
      if(i+1>=argc)
        goto not_enough_args;
      i++; 
@@ -2276,9 +2325,13 @@ problem_handler_2:;
      if(ret <= 0)
        goto problem_handler_boot;
      if(strcmp(argpt, "-isohybrid-mbr")==0)
-       xorriso->system_area_options= (xorriso->system_area_options & ~3) | 2;
+       xorriso->system_area_options=
+                                    (xorriso->system_area_options & ~4001) | 2;
+     else if(strcmp(argpt, "--grub2-mbr") == 0)
+       xorriso->system_area_options= 
+                                  (xorriso->system_area_options & ~2) | 0x4000;
    } else if(strcmp(argpt, "--protective-msdos-label")==0) {
-     xorriso->system_area_options= (xorriso->system_area_options & ~3) | 1;
+     xorriso->system_area_options= (xorriso->system_area_options & ~2) | 1;
    } else if(strcmp(argpt, "--boot-catalog-hide")==0) {
      xorriso->boot_image_cat_hidden|= 3;
    } else if(strcmp(argpt, "-partition_offset") == 0 ||
