@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2013 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -753,8 +753,19 @@ ex:;
 */
 int Xorriso_warn_of_wildcards(struct XorrisO *xorriso, char *path, int flag)
 {
+ static int count_iso= 0, count_disk= 0, max_iso= 3, max_disk= 3;
+
  if(strchr(path,'*')!=NULL || strchr(path,'?')!=NULL ||
     strchr(path,'[')!=NULL) {
+   if(flag & 2) {
+     count_disk++;
+     if(count_disk > max_disk)
+       return(1);
+   } else {
+     count_iso++;
+     if(count_iso > max_iso)
+       return(1);
+   }
    if(flag&1) {
      sprintf(xorriso->info_text,
       "Pattern expansion of wildcards \"*?[\" does not apply to this command");
@@ -764,7 +775,9 @@ int Xorriso_warn_of_wildcards(struct XorrisO *xorriso, char *path, int flag)
             (flag&2) ? "-disk_pattern or -pathspecs" : "-iso_rr_pattern");
    }
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
-   sprintf(xorriso->info_text,"Pattern seen: %s\n", path);
+   sprintf(xorriso->info_text,"Pattern seen: ");
+   Text_shellsafe(path, xorriso->info_text, 1);
+   strcat(xorriso->info_text, "\n");
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
    return(1);
  }
