@@ -852,7 +852,7 @@ treatment_patch:;
    Xorriso_add_mips_boot_file(xorriso, "", 1); /* give up MIPS boot files */
 
  } else if(strncmp(treatpt, "sparc_label=", 12) == 0) {
-   sprintf(eff_path, "-boot_image %s sparc_path=", formpt);
+   sprintf(eff_path, "-boot_image %s sparc_label=", formpt);
    ret= Xorriso_coordinate_system_area(xorriso, 3, 0, eff_path, 0);
    if(ret <= 0)
      goto ex;
@@ -860,6 +860,12 @@ treatment_patch:;
            Xorriso_disc_label_sizE - 1);
    xorriso->ascii_disc_label[Xorriso_disc_label_sizE - 1] = 0;
 
+ } else if(strncmp(treatpt, "grub2_sparc_core=", 17) == 0) {
+   ret= Xorriso_normalize_img_path(xorriso, xorriso->wdi, treatpt + 17,
+                                     xorriso->grub2_sparc_core, 2);
+   if(ret <= 0)
+     goto ex;
+
  } else if(strncmp(treatpt, "boot_info_table=", 16)==0) {
    if(strcmp(treatpt + 16, "off") == 0)
      xorriso->patch_isolinux_image= (xorriso->patch_isolinux_image & ~3) | 0;
@@ -869,6 +875,14 @@ treatment_patch:;
    else
      was_ok= 0;
 
+ } else if(strncmp(treatpt, "grub2_boot_info=", 16)==0) {
+   if(strcmp(treatpt + 16, "off") == 0)
+     xorriso->patch_isolinux_image= xorriso->patch_isolinux_image & ~512;
+   else if(strcmp(treatpt + 16, "on") == 0)
+     xorriso->patch_isolinux_image= xorriso->patch_isolinux_image | 512;
+   else
+     was_ok= 0;
+
  } else if(strncmp(treatpt, "load_size=", 10) == 0) {
    num= Scanf_io_size(treatpt + 10, 0);
    if(num < 512 && isolinux_grub) {
@@ -1118,6 +1132,25 @@ treatment_patch:;
 
 #endif /* ! Xorriso_with_isohybriD */
 
+ } else if(strncmp(treatpt, "grub2_mbr=", 9) == 0 &&
+           strcmp(formpt, "grub")==0) {
+
+   if(strcmp(treatpt + 9, "off") == 0)
+     xorriso->system_area_options&= ~0x4000;
+   else if(strcmp(treatpt + 9, "on") == 0)
+     xorriso->system_area_options=
+                                  (xorriso->system_area_options & ~2) | 0x4000;
+   else {
+     sprintf(xorriso->info_text,
+             "Unrecognized keyword with -boot_image %s %s",
+             form, treatment);
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+     sprintf(xorriso->info_text,
+             "Allowed with grub2_mbr= are: off , on");
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "HINT", 0);
+     {ret= 0; goto ex;}
+   }
+
  } else
    was_ok= 0;
 
