@@ -1463,6 +1463,10 @@ int Xorriso_option_hardlinks(struct XorrisO *xorriso, char *mode, int flag)
      xorriso->ino_behavior&= ~16;
    } else if(strcmp(what, "cheap_sorted_extract") == 0) {
      xorriso->ino_behavior|= 16;
+   } else if(strcmp(what, "lsl_count") == 0) {
+     xorriso->ino_behavior&= ~32;
+   } else if(strcmp(what, "no_lsl_count") == 0) {
+     xorriso->ino_behavior|= 32;
    } else {
      sprintf(xorriso->info_text, "-hardlinks: unknown mode '%s' in '%s'",
              what, mode);
@@ -1626,11 +1630,13 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "  -boot_image \"any\"|\"isolinux\"|\"grub\"",
 "              |\"discard\"|\"keep\"|\"patch\"|\"dir=\"|\"bin_path=\"",
 "              |\"cat_path=\"|\"cat_hidden=on|iso_rr|joliet|off\"",
-"              |\"load_size=\"|\"system_area=\"|\"partition_table=on|off\"",
+"              |\"load_size=\"|\"boot_info_table=\"",
+"              |\"grub2_boot_info=\"|\"grub2_mbr=\"",
+"              |\"system_area=\"|\"partition_table=on|off\"",
 "              |\"chrp_boot_part=on|off=\"|\"prep_boot_part=\"",
 "              |\"efi_boot_part=\"|\"efi_boot_part=--efi-boot-image\"",
 "              |\"mips_path=\"|\"mipsel_path=\"|\"mips_discard\"",
-"              |\"sparc_label=\"|\"sparc_discard\"",
+"              |\"sparc_label=\"|\"grub2_sparc_core=\"|\"sparc_discard\"",
 "              |\"hfsplus_serial=\"|\"hfsplus_block_size=\"",
 "              |\"apm_block_size=\"|\"show_status\"",
 "                 Whether to discard or keep an exiting El Torito boot image.",
