@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2013 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -293,7 +293,7 @@ int Xorriso_option_print_size(struct XorrisO *xorriso, int flag)
 {
  int ret, fd;
 
- if(!xorriso->volset_change_pending) {
+ if(!Xorriso_change_is_pending(xorriso, 0)) {
    sprintf(xorriso->info_text,"-print_size: No image modifications pending");
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
    if(!(flag & 1)) {
@@ -440,17 +440,6 @@ int Xorriso_option_reassure(struct XorrisO *xorriso, char *mode, int flag)
 }
 
 
-/* Option -unregister_filter */
-int Xorriso_option_unregister_filter(struct XorrisO *xorriso, char *name,
-                                     int flag)
-{
- int ret;
-
- ret= Xorriso_external_filter(xorriso, name, "", "", 0, NULL, 1);
- return(ret);
-}
-
-
 /* Option -report_about */
 int Xorriso_option_report_about(struct XorrisO *xorriso, char *in_severity,
                                 int flag)
@@ -576,6 +565,22 @@ ex:;
 }
 
 
+/* Option -rockridge "on"|"off" */
+int Xorriso_option_rockridge(struct XorrisO *xorriso, char *mode, int flag)
+{
+ if(strcmp(mode, "off")==0)
+   xorriso->do_rockridge= 0;
+ else if(strcmp(mode, "on")==0)
+   xorriso->do_rockridge= 1;
+ else {
+   sprintf(xorriso->info_text, "-rockridge: unknown mode '%s'", mode);
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ return(1);
+}
+
+
 /* Option -rollback */
 /* @param flag bit0= do not -reassure
    @return <=0 error , 1 success, 2 revoked by -reassure
@@ -586,7 +591,7 @@ int Xorriso_option_rollback(struct XorrisO *xorriso, int flag)
  char *indev= NULL, *which_will;
 
  Xorriso_alloc_meM(indev, char, SfileadrL);
- if(xorriso->volset_change_pending)
+ if(Xorriso_change_is_pending(xorriso, 0))
    which_will= "revoke the pending image changes";
  else
    which_will= "reload the image";
@@ -598,6 +603,7 @@ int Xorriso_option_rollback(struct XorrisO *xorriso, int flag)
 
  if(Sfile_str(indev, xorriso->indev, 0)<=0)
    {ret= -1; goto ex;}
+ xorriso->volset_change_pending= 0;
  ret= Xorriso_give_up_drive(xorriso, 1|8);
  if(ret<=0)
    goto ex;
@@ -615,7 +621,6 @@ int Xorriso_option_rom_toc_scan(struct XorrisO *xorriso, char *mode, int flag)
  int l;
  char *cpt, *npt;
 
- xorriso->toc_emulation_flag= 0;
  npt= cpt= mode;
  for(cpt= mode; npt != NULL; cpt= npt + 1) {
    npt= strchr(cpt,':');
@@ -624,20 +629,22 @@ int Xorriso_option_rom_toc_scan(struct XorrisO *xorriso, char *mode, int flag)
    else
      l= npt-cpt;
    if(l==0)
-     goto unknown_mode;
-   xorriso->toc_emulation_flag&= ~4;
+ continue;
    if(strncmp(cpt, "off", l) == 0)
-     xorriso->toc_emulation_flag&= ~1;
+     xorriso->toc_emulation_flag&= ~5;
    else if(strncmp(cpt, "on", l) == 0)
-     xorriso->toc_emulation_flag|= 1;
+     xorriso->toc_emulation_flag= (xorriso->toc_emulation_flag & ~4) | 1;
    else if(strncmp(cpt, "force", l) == 0)
-     xorriso->toc_emulation_flag|= 4;
+     xorriso->toc_emulation_flag|= 5;
    else if(strncmp(cpt, "emul_off", l) == 0)
      xorriso->toc_emulation_flag|= 2;
    else if(strncmp(cpt, "emul_on", l) == 0)
      xorriso->toc_emulation_flag&= ~2;
+   else if(strncmp(cpt, "emul_wide", l) == 0)
+     xorriso->toc_emulation_flag|= 8;
+   else if(strncmp(cpt, "emul_narrow", l) == 0)
+     xorriso->toc_emulation_flag&= ~8;
    else {
-unknown_mode:;
      sprintf(xorriso->info_text, "-rom_toc_scan: unknown mode in '%s'", mode);
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
      return(0);
@@ -647,6 +654,26 @@ unknown_mode:;
 }
 
 
+/* Command -rr_reloc_dir */
+int Xorriso_option_rr_reloc_dir(struct XorrisO *xorriso, char *name, int flag)
+{
+ if(strlen(name) > 255) {
+   sprintf(xorriso->info_text,
+           "Name too long with -rr_reloc_dir. Max. 255 bytes allowed.");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ if(strchr(name, '/') != NULL) {
+   sprintf(xorriso->info_text,
+           "Name given with -rr_reloc_dir contains '/' character");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ strcpy(xorriso->rr_reloc_dir, name);
+ return(1);
+}
+
+
 /* Option -scdbackup_tag list_path record_name */
 int Xorriso_option_scdbackup_tag(struct XorrisO *xorriso, char *listname,
                                  char *recname, int flag)
@@ -1460,6 +1487,8 @@ int Xorriso_option_temp_mem_limit(struct XorrisO *xorriso, char *size,
 
 
 /* Option -toc */
+/* @param flag   bit0= short report form as with -dev, no table-of-content
+*/
 int Xorriso_option_toc(struct XorrisO *xorriso, int flag)
 {
  int ret, in_ret= 1000;
@@ -1475,7 +1504,7 @@ int Xorriso_option_toc(struct XorrisO *xorriso, int flag)
    }
    ret= 1;
    if(xorriso->outdev[0]!=0)
-     ret= Xorriso_toc(xorriso, 2);
+     ret= Xorriso_toc(xorriso, 2 | (flag & 1));
    if(in_ret<ret)
      ret= in_ret;
  }
@@ -1483,6 +1512,44 @@ int Xorriso_option_toc(struct XorrisO *xorriso, int flag)
 }
 
 
+/* Option -toc_of */
+int Xorriso_option_toc_of(struct XorrisO *xorriso, char *which, int flag)
+{
+ int ret= 0, toc_flag= 0;
+
+ if(strstr(which, ":short") != NULL)
+   toc_flag|= 1;
+ if(strncmp(which, "in", 2) == 0) {
+   if(xorriso->indev[0] == 0) {
+     Xorriso_msgs_submit(xorriso, 0, "-toc_of 'in' : No input drive aquired",
+                         0, "NOTE", 0);
+     return(2);
+   }
+   ret= Xorriso_toc(xorriso, toc_flag | 0);
+ } else if(strncmp(which, "out", 3) == 0) {
+   if(xorriso->outdev[0] == 0) {
+     Xorriso_msgs_submit(xorriso, 0, "-toc_of 'out' : No output drive aquired",
+                         0, "NOTE", 0);
+     return(2);
+   }
+   ret= Xorriso_toc(xorriso, toc_flag | 2);
+ } else if(strncmp(which, "all", 3) == 0) {
+   if(xorriso->indev[0] == 0 && xorriso->outdev[0] == 0) {
+     Xorriso_msgs_submit(xorriso, 0, "-toc_of 'all' : No drive aquired",
+                         0, "NOTE", 0);
+     return(2);
+   }
+   ret= Xorriso_option_toc(xorriso, toc_flag | 0);
+ } else {
+   sprintf(xorriso->info_text, "-toc_of: Unknown drive code ");
+   Text_shellsafe(which, xorriso->info_text, 1);
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+   ret= 0;
+ }
+ return(ret);
+}
+
+
 /* Option -uid */
 int Xorriso_option_uid(struct XorrisO *xorriso, char *uid, int flag)
 {
@@ -1498,6 +1565,17 @@ int Xorriso_option_uid(struct XorrisO *xorriso, char *uid, int flag)
 }
 
 
+/* Option -unregister_filter */
+int Xorriso_option_unregister_filter(struct XorrisO *xorriso, char *name,
+                                     int flag)
+{
+ int ret;
+
+ ret= Xorriso_external_filter(xorriso, name, "", "", 0, NULL, 1);
+ return(ret);
+}
+
+
 /* Options -update and -update_r
    @param flag bit0= issue start and summary message
                bit1= do not reset pacifier, no final pacifier message
@@ -1738,15 +1816,16 @@ int Xorriso_option_version(struct XorrisO *xorriso, int flag)
  sprintf(xorriso->result_line,
 "ISO 9660 Rock Ridge filesystem manipulator and CD/DVD/BD burn program\n");
  sprintf(xorriso->result_line+strlen(xorriso->result_line),
-"Copyright (C) 2012, Thomas Schmitt <scdbackup@gmx.net>, libburnia project.\n");
+"Copyright (C) 2013, Thomas Schmitt <scdbackup@gmx.net>, libburnia project.\n");
  Xorriso_result(xorriso, 0);
  sprintf(xorriso->result_line,
          "xorriso version   :  %d.%d.%d%s\n",
          Xorriso_header_version_majoR, Xorriso_header_version_minoR,
          Xorriso_header_version_micrO, Xorriso_program_patch_leveL);
- sprintf(xorriso->result_line+strlen(xorriso->result_line),
-         "Version timestamp :  %s\n",Xorriso_timestamP);
- sprintf(xorriso->result_line+strlen(xorriso->result_line),
+ Xorriso_result(xorriso, 0);
+ sprintf(xorriso->result_line, "Version timestamp :  %s\n",Xorriso_timestamP);
+ Xorriso_result(xorriso, 0);
+ sprintf(xorriso->result_line,
          "Build timestamp   :  %s\n",Xorriso_build_timestamP);
  Xorriso_result(xorriso, 0);
  Xorriso_report_lib_versions(xorriso, 0);
@@ -1886,6 +1965,26 @@ ex:;
 }
 
 
+/* Command -write_type */
+int Xorriso_option_write_type(struct XorrisO *xorriso, char *mode, int flag)
+{
+ if(strcmp(mode, "auto") == 0)
+   xorriso->do_tao = 0;
+ else if(strcmp(mode, "tao") == 0 || strcmp(mode, "TAO") == 0) 
+   xorriso->do_tao = 1;
+ else if(strcmp(mode, "sao") == 0 || strcmp(mode, "SAO") == 0 ||
+         strcmp(mode, "dao") == 0 || strcmp(mode, "DAO") == 0 ||
+         strcmp(mode, "sao/dao") == 0 || strcmp(mode, "SAO/DAO") == 0 ) 
+   xorriso->do_tao = -1;
+ else {
+   sprintf(xorriso->info_text, "-write_type: unknown mode '%s'", mode);
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ return(1);
+}
+
+
 /* Option -xattr "on"|"off" */
 int Xorriso_option_xattr(struct XorrisO *xorriso, char *mode, int flag)
 {
