@@ -88,5 +88,10 @@ int Xorriso_normalize_acl_text(struct XorrisO *xorriso, char *in_text,
 
 int Xorriso_read_mkisofsrc(struct XorrisO *xorriso, int flag);
 
+/* @param flag bit0= list sorting order rather than looking for argv[idx]
+*/
+int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
+                        int argc, char **argv, int idx, int flag);
+
 #endif /* ! Xorriso_pvt_cmd_includeD */
 
