@@ -311,9 +311,37 @@ int Xorriso_set_system_area(struct XorrisO *xorriso, struct burn_drive *drive,
  unsigned char *ub;
  ElToritoBootImage *bootimg;
  IsoFile *bootimg_node;
+ IsoNode *sparc_core_node;
  uint32_t offst;
  enum burn_disc_status state;
 
+ if(xorriso->grub2_sparc_core[0]) {
+   ret= Xorriso_node_from_path(xorriso, img, xorriso->grub2_sparc_core,
+                               &sparc_core_node, 1);
+   if(ret <= 0) {
+     sprintf(xorriso->info_text,
+             "Cannot find in ISO image: -boot_image grub grub2_sparc_core=");
+     Text_shellsafe(xorriso->grub2_sparc_core, xorriso->info_text, 1);
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+     {ret= 0; goto ex;}
+   }
+   if(!ISO_NODE_IS_FILE(sparc_core_node)) {
+     sprintf(xorriso->info_text,
+             "Not a data file: -boot_image grub grub2_sparc_core=");
+     Text_shellsafe(xorriso->grub2_sparc_core, xorriso->info_text, 1);
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+     {ret= 0; goto ex;}
+   }
+   ret = iso_image_set_sparc_core(img, (IsoFile *) sparc_core_node, 0);
+   if(ret < 0) {
+     Xorriso_process_msg_queues(xorriso,0);
+     Xorriso_report_iso_error(xorriso, "", ret,
+                    "Error when setting up -boot_image grub grub2_sparc_core=",
+                     0, "FAILURE", 1);
+     {ret= 0; goto ex;}
+   }
+ }
+
  Xorriso_alloc_meM(buf, char, 32768);
  system_area_options= xorriso->system_area_options;
  memset(buf, 0, 32768);
@@ -748,7 +776,7 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
    goto ex;
 
  /* Activate, adjust or discard boot image */
- if(image!=NULL && !(flag&1)) {
+ if(image!=NULL) {
    is_bootable= iso_image_get_boot_image(image, NULL, NULL, &bootcat_node);
    if(xorriso->boot_image_bin_path[0]) {
      ret= Xorriso_attach_boot_image(xorriso, xorriso->boot_count == 0);
@@ -756,6 +784,8 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
        goto ex;
      freshly_bootable= 1;
    }
+ }
+ if(image!=NULL && !(flag&1)) {
    if(xorriso->boot_count > 0) {
      /* Eventually rename boot catalog node to changed boot_image_cat_path */
      if(is_bootable > 0) {
@@ -2365,7 +2395,7 @@ int Xorriso_set_isolinux_options(struct XorrisO *xorriso,
  }
 
  /* bit0 : 1=boot-info-table , bit2-7 : 1=EFI , 2=HFS+ , bit8 : 1=APM */
- patch_table = xorriso->patch_isolinux_image & 0x1fd;
+ patch_table = xorriso->patch_isolinux_image & 0x3fd;
  if((flag & 1) && num_boots > 1) {
    ret= el_torito_set_isolinux_options(boots[num_boots - 1], patch_table, 0);
    ret= (ret == 1); goto ex;
@@ -2374,7 +2404,7 @@ int Xorriso_set_isolinux_options(struct XorrisO *xorriso,
  /* Handle patching of first attached boot image or of imported boot images 
  */
  for(i= 0; i < num_boots; i++) {
-   patch_table = xorriso->patch_isolinux_image & 0x1fd;
+   patch_table = xorriso->patch_isolinux_image & 0x3fd;
    if(patch_table && !(flag & 1)) {
      if(!el_torito_seems_boot_info_table(boots[i], 0))
        patch_table&= ~1;
