@@ -135,6 +135,8 @@ struct XorrisO { /* the global context of xorriso */
                             Do not try to detect hardlink splits and joinings.
                       bit4= with extract:
                             Do not create or use hln arrays if sort_lba_on
+                      bit5= with command -lsl
+                            Do not create hln array for hard link count
                     */
 
  int iso_level;
@@ -364,6 +366,7 @@ struct XorrisO { /* the global context of xorriso */
                               bit2-7= Mentioning in isohybrid GPT
                                       1=EFI, 2=HFS+
                               bit8= Mention in isohybrid Apple Partition Map
+                              bit9= GRUB2 boot provisions (patch at byte 1012)
                             */
  int boot_image_emul; /* 0=no emulation
                          1=emulation as hard disk
@@ -405,6 +408,14 @@ struct XorrisO { /* the global context of xorriso */
                                                    any other feature which
                                                    needs to have own MBR
                                                    partition entries.
+                                         bit14= Only with System area type 0
+                                               GRUB2 boot provisions:
+                                               Patch system area at byte 92 to
+                                               99 with 512-block address + 1
+                                               of the first boot image file.
+                                               Little-endian 8-byte.
+                                               Should be combined with
+                                               options bit0.
                                        */
  int patch_system_area;               /* Bits as of system_area_options.
                                          to be applied to the loaded system
@@ -434,6 +445,11 @@ struct XorrisO { /* the global context of xorriso */
  */
  char ascii_disc_label[Xorriso_disc_label_sizE];
 
+ /* A data file of which the position and size shall be written after
+    a SUN Disk Label.
+ */
+ char grub2_sparc_core[SfileadrL];
+
  /* HFS+ image serial number.
     00...00 means that it shall be generated by libisofs.
  */
